# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FederatedClaimArgs', 'FederatedClaim']

@pulumi.input_type
class FederatedClaimArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 expression: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FederatedClaim resource.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Input[_builtins.str]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FederatedClaimState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FederatedClaim resources.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("okta:app/federatedClaim:FederatedClaim")
class FederatedClaim(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a federated claim for an Okta application.

        Federated claims allow you to pass user information from Okta to your app integrations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        example = okta.app.FederatedClaim("example",
            app_id=test_app.id,
            name="role_last_name",
            expression="user.profile.lastName")
        ```

        ### Multiple Claims Example

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        last_name = okta.app.FederatedClaim("last_name",
            app_id=test_app.id,
            name="lastName",
            expression="user.profile.lastName")
        first_name = okta.app.FederatedClaim("first_name",
            app_id=test_app.id,
            name="firstName",
            expression="user.profile.firstName")
        department = okta.app.FederatedClaim("department",
            app_id=test_app.id,
            name="department",
            expression="user.profile.department")
        ```

        ## Import

        An app federated claim can be imported using the format `app_id/id`:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example <app_id>/<id>
        ```

        Example:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example 0oa1234567890abcdef/clm1234567890abcdef
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FederatedClaimArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a federated claim for an Okta application.

        Federated claims allow you to pass user information from Okta to your app integrations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        example = okta.app.FederatedClaim("example",
            app_id=test_app.id,
            name="role_last_name",
            expression="user.profile.lastName")
        ```

        ### Multiple Claims Example

        ```python
        import pulumi
        import pulumi_okta as okta

        test_app = okta.app.Saml("test_app",
            label="example",
            sso_url="https://example.com",
            recipient="https://example.com",
            destination="https://example.com",
            audience="https://example.com/audience",
            subject_name_id_template="${user.userName}",
            subject_name_id_format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
            response_signed=True,
            signature_algorithm="RSA_SHA256",
            digest_algorithm="SHA256")
        last_name = okta.app.FederatedClaim("last_name",
            app_id=test_app.id,
            name="lastName",
            expression="user.profile.lastName")
        first_name = okta.app.FederatedClaim("first_name",
            app_id=test_app.id,
            name="firstName",
            expression="user.profile.firstName")
        department = okta.app.FederatedClaim("department",
            app_id=test_app.id,
            name="department",
            expression="user.profile.department")
        ```

        ## Import

        An app federated claim can be imported using the format `app_id/id`:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example <app_id>/<id>
        ```

        Example:

        ```sh
        $ pulumi import okta:app/federatedClaim:FederatedClaim example 0oa1234567890abcdef/clm1234567890abcdef
        ```


        :param str resource_name: The name of the resource.
        :param FederatedClaimArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FederatedClaimArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FederatedClaimArgs.__new__(FederatedClaimArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if expression is None and not opts.urn:
                raise TypeError("Missing required property 'expression'")
            __props__.__dict__["expression"] = expression
            __props__.__dict__["name"] = name
        super(FederatedClaim, __self__).__init__(
            'okta:app/federatedClaim:FederatedClaim',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            expression: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'FederatedClaim':
        """
        Get an existing FederatedClaim resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to add the federated claim to.
        :param pulumi.Input[_builtins.str] expression: The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        :param pulumi.Input[_builtins.str] name: The name of the claim to be used in the produced token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FederatedClaimState.__new__(_FederatedClaimState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["expression"] = expression
        __props__.__dict__["name"] = name
        return FederatedClaim(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the application to add the federated claim to.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Output[_builtins.str]:
        """
        The Okta Expression Language expression to be evaluated at runtime. See [Okta Expression Language](https://developer.okta.com/docs/reference/okta-expression-language/) for more information.
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the claim to be used in the produced token.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupAssignmentArgs', 'GroupAssignment']

@pulumi.input_type
class GroupAssignmentArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 group_id: pulumi.Input[_builtins.str],
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GroupAssignment resource.

        :param pulumi.Input[_builtins.str] app_id: App to associate group with
        :param pulumi.Input[_builtins.str] group_id: Group associated with the application
        :param pulumi.Input[_builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[_builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "group_id", group_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[_builtins.str]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)


@pulumi.input_type
class _GroupAssignmentState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GroupAssignment resources.

        :param pulumi.Input[_builtins.str] app_id: App to associate group with
        :param pulumi.Input[_builtins.str] group_id: Group associated with the application
        :param pulumi.Input[_builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[_builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if profile is not None:
            pulumi.set(__self__, "profile", profile)
        if retain_assignment is not None:
            pulumi.set(__self__, "retain_assignment", retain_assignment)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_id", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @profile.setter
    def profile(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "profile", value)

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")

    @retain_assignment.setter
    def retain_assignment(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "retain_assignment", value)


@pulumi.type_token("okta:app/groupAssignment:GroupAssignment")
class GroupAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Assigns a group to an application. This resource allows you to create an App Group assignment.

        > **IMPORTANT:** When the `app_group_assignment` is retained, by
        setting `retain_assignment` to `true`, it is no longer managed by
        Terraform after it is destroyed. To truly delete the assignment,
        you will need to remove it either through the Okta Console or API.
        This argument exists for the use case where the same group is
        assigned in multiple places in order to prevent a single
        destruction removing all of them.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.GroupAssignment("example",
            app_id="<app id>",
            group_id="<group id>",
            profile=\"\"\"{
          \\"<app_profile_field>\\": \\"<value>\\"
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/groupAssignment:GroupAssignment example <app_id>/<group_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: App to associate group with
        :param pulumi.Input[_builtins.str] group_id: Group associated with the application
        :param pulumi.Input[_builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[_builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Assigns a group to an application. This resource allows you to create an App Group assignment.

        > **IMPORTANT:** When the `app_group_assignment` is retained, by
        setting `retain_assignment` to `true`, it is no longer managed by
        Terraform after it is destroyed. To truly delete the assignment,
        you will need to remove it either through the Okta Console or API.
        This argument exists for the use case where the same group is
        assigned in multiple places in order to prevent a single
        destruction removing all of them.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.app.GroupAssignment("example",
            app_id="<app id>",
            group_id="<group id>",
            profile=\"\"\"{
          \\"<app_profile_field>\\": \\"<value>\\"
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import okta:app/groupAssignment:GroupAssignment example <app_id>/<group_id>
        ```


        :param str resource_name: The name of the resource.
        :param GroupAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 profile: Optional[pulumi.Input[_builtins.str]] = None,
                 retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupAssignmentArgs.__new__(GroupAssignmentArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["priority"] = priority
            __props__.__dict__["profile"] = profile
            __props__.__dict__["retain_assignment"] = retain_assignment
        super(GroupAssignment, __self__).__init__(
            'okta:app/groupAssignment:GroupAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            group_id: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            profile: Optional[pulumi.Input[_builtins.str]] = None,
            retain_assignment: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GroupAssignment':
        """
        Get an existing GroupAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: App to associate group with
        :param pulumi.Input[_builtins.str] group_id: Group associated with the application
        :param pulumi.Input[_builtins.int] priority: Priority of group assignment.
        :param pulumi.Input[_builtins.str] profile: JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        :param pulumi.Input[_builtins.bool] retain_assignment: Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupAssignmentState.__new__(_GroupAssignmentState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["priority"] = priority
        __props__.__dict__["profile"] = profile
        __props__.__dict__["retain_assignment"] = retain_assignment
        return GroupAssignment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        App to associate group with
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[_builtins.str]:
        """
        Group associated with the application
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Priority of group assignment.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        JSON document containing [application profile](https://developer.okta.com/docs/reference/api/apps/#profile-object)
        """
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter(name="retainAssignment")
    def retain_assignment(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Retain the group assignment on destroy. If set to true, the resource will be removed from state but not from the Okta app.
        """
        return pulumi.get(self, "retain_assignment")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppUserSchemaPropertyArgs', 'AppUserSchemaProperty']

@pulumi.input_type
class AppUserSchemaPropertyArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 index: pulumi.Input[_builtins.str],
                 title: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 array_enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 array_one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]] = None,
                 array_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 external_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 max_length: Optional[pulumi.Input[_builtins.int]] = None,
                 min_length: Optional[pulumi.Input[_builtins.int]] = None,
                 one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 union: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AppUserSchemaProperty resource.

        :param pulumi.Input[_builtins.str] app_id: The Application's ID the user custom schema property should be assigned to.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]] array_one_ofs: Display name and value an enum array can be set to.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] array_type: The type of the array elements if `type` is set to `array`
        :param pulumi.Input[_builtins.str] description: The description of the user schema property.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[_builtins.str] external_name: External name of the user schema property.
        :param pulumi.Input[_builtins.str] external_namespace: External namespace of the user schema property.
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        :param pulumi.Input[_builtins.int] max_length: The maximum length of the user property value. Only applies to type `string`
        :param pulumi.Input[_builtins.int] min_length: The minimum length of the user property value. Only applies to type `string`
        :param pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]] one_ofs: Array of maps containing a mapping for display name to enum value.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] scope: determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        :param pulumi.Input[_builtins.bool] union: If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        :param pulumi.Input[_builtins.str] unique: Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "index", index)
        pulumi.set(__self__, "title", title)
        pulumi.set(__self__, "type", type)
        if array_enums is not None:
            pulumi.set(__self__, "array_enums", array_enums)
        if array_one_ofs is not None:
            pulumi.set(__self__, "array_one_ofs", array_one_ofs)
        if array_type is not None:
            pulumi.set(__self__, "array_type", array_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enums is not None:
            pulumi.set(__self__, "enums", enums)
        if external_name is not None:
            pulumi.set(__self__, "external_name", external_name)
        if external_namespace is not None:
            pulumi.set(__self__, "external_namespace", external_namespace)
        if master is not None:
            pulumi.set(__self__, "master", master)
        if max_length is not None:
            pulumi.set(__self__, "max_length", max_length)
        if min_length is not None:
            pulumi.set(__self__, "min_length", min_length)
        if one_ofs is not None:
            pulumi.set(__self__, "one_ofs", one_ofs)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if required is not None:
            pulumi.set(__self__, "required", required)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)
        if union is not None:
            pulumi.set(__self__, "union", union)
        if unique is not None:
            pulumi.set(__self__, "unique", unique)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Application's ID the user custom schema property should be assigned to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Input[_builtins.str]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Input[_builtins.str]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="arrayEnums")
    def array_enums(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values that an array property's items can be set to.
        """
        return pulumi.get(self, "array_enums")

    @array_enums.setter
    def array_enums(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "array_enums", value)

    @_builtins.property
    @pulumi.getter(name="arrayOneOfs")
    def array_one_ofs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]]:
        """
        Display name and value an enum array can be set to.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "array_one_ofs")

    @array_one_ofs.setter
    def array_one_ofs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]]):
        pulumi.set(self, "array_one_ofs", value)

    @_builtins.property
    @pulumi.getter(name="arrayType")
    def array_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the array elements if `type` is set to `array`
        """
        return pulumi.get(self, "array_type")

    @array_type.setter
    def array_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "array_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the user schema property.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enums(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values a primitive property can be set to. See `array_enum` for arrays.
        """
        return pulumi.get(self, "enums")

    @enums.setter
    def enums(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enums", value)

    @_builtins.property
    @pulumi.getter(name="externalName")
    def external_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External name of the user schema property.
        """
        return pulumi.get(self, "external_name")

    @external_name.setter
    def external_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_name", value)

    @_builtins.property
    @pulumi.getter(name="externalNamespace")
    def external_namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External namespace of the user schema property.
        """
        return pulumi.get(self, "external_namespace")

    @external_namespace.setter
    def external_namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_namespace", value)

    @_builtins.property
    @pulumi.getter
    def master(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        """
        return pulumi.get(self, "master")

    @master.setter
    def master(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master", value)

    @_builtins.property
    @pulumi.getter(name="maxLength")
    def max_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "max_length")

    @max_length.setter
    def max_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_length", value)

    @_builtins.property
    @pulumi.getter(name="minLength")
    def min_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "min_length")

    @min_length.setter
    def min_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_length", value)

    @_builtins.property
    @pulumi.getter(name="oneOfs")
    def one_ofs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]]:
        """
        Array of maps containing a mapping for display name to enum value.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "one_ofs")

    @one_ofs.setter
    def one_ofs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]]):
        pulumi.set(self, "one_ofs", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter
    def required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @required.setter
    def required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "required", value)

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "scope", value)

    @_builtins.property
    @pulumi.getter
    def union(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        """
        return pulumi.get(self, "union")

    @union.setter
    def union(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "union", value)

    @_builtins.property
    @pulumi.getter
    def unique(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        """
        return pulumi.get(self, "unique")

    @unique.setter
    def unique(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unique", value)

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_type", value)


@pulumi.input_type
class _AppUserSchemaPropertyState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 array_enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 array_one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]] = None,
                 array_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 external_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 max_length: Optional[pulumi.Input[_builtins.int]] = None,
                 min_length: Optional[pulumi.Input[_builtins.int]] = None,
                 one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 union: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AppUserSchemaProperty resources.

        :param pulumi.Input[_builtins.str] app_id: The Application's ID the user custom schema property should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]] array_one_ofs: Display name and value an enum array can be set to.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] array_type: The type of the array elements if `type` is set to `array`
        :param pulumi.Input[_builtins.str] description: The description of the user schema property.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[_builtins.str] external_name: External name of the user schema property.
        :param pulumi.Input[_builtins.str] external_namespace: External namespace of the user schema property.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        :param pulumi.Input[_builtins.int] max_length: The maximum length of the user property value. Only applies to type `string`
        :param pulumi.Input[_builtins.int] min_length: The minimum length of the user property value. Only applies to type `string`
        :param pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]] one_ofs: Array of maps containing a mapping for display name to enum value.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] scope: determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.bool] union: If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        :param pulumi.Input[_builtins.str] unique: Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if array_enums is not None:
            pulumi.set(__self__, "array_enums", array_enums)
        if array_one_ofs is not None:
            pulumi.set(__self__, "array_one_ofs", array_one_ofs)
        if array_type is not None:
            pulumi.set(__self__, "array_type", array_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enums is not None:
            pulumi.set(__self__, "enums", enums)
        if external_name is not None:
            pulumi.set(__self__, "external_name", external_name)
        if external_namespace is not None:
            pulumi.set(__self__, "external_namespace", external_namespace)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if master is not None:
            pulumi.set(__self__, "master", master)
        if max_length is not None:
            pulumi.set(__self__, "max_length", max_length)
        if min_length is not None:
            pulumi.set(__self__, "min_length", min_length)
        if one_ofs is not None:
            pulumi.set(__self__, "one_ofs", one_ofs)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if required is not None:
            pulumi.set(__self__, "required", required)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if union is not None:
            pulumi.set(__self__, "union", union)
        if unique is not None:
            pulumi.set(__self__, "unique", unique)
        if user_type is not None:
            pulumi.set(__self__, "user_type", user_type)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Application's ID the user custom schema property should be assigned to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="arrayEnums")
    def array_enums(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values that an array property's items can be set to.
        """
        return pulumi.get(self, "array_enums")

    @array_enums.setter
    def array_enums(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "array_enums", value)

    @_builtins.property
    @pulumi.getter(name="arrayOneOfs")
    def array_one_ofs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]]:
        """
        Display name and value an enum array can be set to.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "array_one_ofs")

    @array_one_ofs.setter
    def array_one_ofs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyArrayOneOfArgs']]]]):
        pulumi.set(self, "array_one_ofs", value)

    @_builtins.property
    @pulumi.getter(name="arrayType")
    def array_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the array elements if `type` is set to `array`
        """
        return pulumi.get(self, "array_type")

    @array_type.setter
    def array_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "array_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the user schema property.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enums(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of values a primitive property can be set to. See `array_enum` for arrays.
        """
        return pulumi.get(self, "enums")

    @enums.setter
    def enums(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enums", value)

    @_builtins.property
    @pulumi.getter(name="externalName")
    def external_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External name of the user schema property.
        """
        return pulumi.get(self, "external_name")

    @external_name.setter
    def external_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_name", value)

    @_builtins.property
    @pulumi.getter(name="externalNamespace")
    def external_namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        External namespace of the user schema property.
        """
        return pulumi.get(self, "external_namespace")

    @external_namespace.setter
    def external_namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "external_namespace", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter
    def master(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        """
        return pulumi.get(self, "master")

    @master.setter
    def master(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master", value)

    @_builtins.property
    @pulumi.getter(name="maxLength")
    def max_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "max_length")

    @max_length.setter
    def max_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_length", value)

    @_builtins.property
    @pulumi.getter(name="minLength")
    def min_length(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "min_length")

    @min_length.setter
    def min_length(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_length", value)

    @_builtins.property
    @pulumi.getter(name="oneOfs")
    def one_ofs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]]:
        """
        Array of maps containing a mapping for display name to enum value.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "one_ofs")

    @one_ofs.setter
    def one_ofs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppUserSchemaPropertyOneOfArgs']]]]):
        pulumi.set(self, "one_ofs", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter
    def required(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @required.setter
    def required(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "required", value)

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "scope", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def union(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        """
        return pulumi.get(self, "union")

    @union.setter
    def union(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "union", value)

    @_builtins.property
    @pulumi.getter
    def unique(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        """
        return pulumi.get(self, "unique")

    @unique.setter
    def unique(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unique", value)

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")

    @user_type.setter
    def user_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_type", value)


@pulumi.type_token("okta:index/appUserSchemaProperty:AppUserSchemaProperty")
class AppUserSchemaProperty(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 array_enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 array_one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyArrayOneOfArgs', 'AppUserSchemaPropertyArrayOneOfArgsDict']]]]] = None,
                 array_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 external_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 max_length: Optional[pulumi.Input[_builtins.int]] = None,
                 min_length: Optional[pulumi.Input[_builtins.int]] = None,
                 one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyOneOfArgs', 'AppUserSchemaPropertyOneOfArgsDict']]]]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 union: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an Application User Schema property.
        This resource allows you to create and configure a custom user schema property and associate it with an application.
        Make sure that the app instance is 'active' before creating the schema property, because in some cases API might return '404' error.
        **IMPORTANT:** With 'enum', list its values as strings even though the 'type'
        may be something other than string. This is a limitation of the schema defintion
        in the Terraform Plugin SDK runtime and we juggle the type correctly when making
        Okta API calls. Same holds for the 'const' value of 'one_of' as well as the
        'array_*' variation of 'enum' and 'one_of'

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AppUserSchemaProperty("example",
            app_id="<app id>",
            index="customPropertyName",
            title="customPropertyName",
            type="string",
            description="My custom property name",
            master="OKTA",
            scope="SELF",
            array_enums=[
                "1",
                "2",
            ],
            array_one_ofs=[
                {
                    "const": "1",
                    "title": "one",
                },
                {
                    "const": "2",
                    "title": "two",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appUserSchemaProperty:AppUserSchemaProperty example <app_id>/<property_name>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The Application's ID the user custom schema property should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyArrayOneOfArgs', 'AppUserSchemaPropertyArrayOneOfArgsDict']]]] array_one_ofs: Display name and value an enum array can be set to.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] array_type: The type of the array elements if `type` is set to `array`
        :param pulumi.Input[_builtins.str] description: The description of the user schema property.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[_builtins.str] external_name: External name of the user schema property.
        :param pulumi.Input[_builtins.str] external_namespace: External namespace of the user schema property.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        :param pulumi.Input[_builtins.int] max_length: The maximum length of the user property value. Only applies to type `string`
        :param pulumi.Input[_builtins.int] min_length: The minimum length of the user property value. Only applies to type `string`
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyOneOfArgs', 'AppUserSchemaPropertyOneOfArgsDict']]]] one_ofs: Array of maps containing a mapping for display name to enum value.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] scope: determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.bool] union: If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        :param pulumi.Input[_builtins.str] unique: Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppUserSchemaPropertyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Application User Schema property.
        This resource allows you to create and configure a custom user schema property and associate it with an application.
        Make sure that the app instance is 'active' before creating the schema property, because in some cases API might return '404' error.
        **IMPORTANT:** With 'enum', list its values as strings even though the 'type'
        may be something other than string. This is a limitation of the schema defintion
        in the Terraform Plugin SDK runtime and we juggle the type correctly when making
        Okta API calls. Same holds for the 'const' value of 'one_of' as well as the
        'array_*' variation of 'enum' and 'one_of'

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.AppUserSchemaProperty("example",
            app_id="<app id>",
            index="customPropertyName",
            title="customPropertyName",
            type="string",
            description="My custom property name",
            master="OKTA",
            scope="SELF",
            array_enums=[
                "1",
                "2",
            ],
            array_one_ofs=[
                {
                    "const": "1",
                    "title": "one",
                },
                {
                    "const": "2",
                    "title": "two",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appUserSchemaProperty:AppUserSchemaProperty example <app_id>/<property_name>
        ```


        :param str resource_name: The name of the resource.
        :param AppUserSchemaPropertyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppUserSchemaPropertyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 array_enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 array_one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyArrayOneOfArgs', 'AppUserSchemaPropertyArrayOneOfArgsDict']]]]] = None,
                 array_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 external_name: Optional[pulumi.Input[_builtins.str]] = None,
                 external_namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 index: Optional[pulumi.Input[_builtins.str]] = None,
                 master: Optional[pulumi.Input[_builtins.str]] = None,
                 max_length: Optional[pulumi.Input[_builtins.int]] = None,
                 min_length: Optional[pulumi.Input[_builtins.int]] = None,
                 one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyOneOfArgs', 'AppUserSchemaPropertyOneOfArgsDict']]]]] = None,
                 permissions: Optional[pulumi.Input[_builtins.str]] = None,
                 required: Optional[pulumi.Input[_builtins.bool]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 union: Optional[pulumi.Input[_builtins.bool]] = None,
                 unique: Optional[pulumi.Input[_builtins.str]] = None,
                 user_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppUserSchemaPropertyArgs.__new__(AppUserSchemaPropertyArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["array_enums"] = array_enums
            __props__.__dict__["array_one_ofs"] = array_one_ofs
            __props__.__dict__["array_type"] = array_type
            __props__.__dict__["description"] = description
            __props__.__dict__["enums"] = enums
            __props__.__dict__["external_name"] = external_name
            __props__.__dict__["external_namespace"] = external_namespace
            if index is None and not opts.urn:
                raise TypeError("Missing required property 'index'")
            __props__.__dict__["index"] = index
            __props__.__dict__["master"] = master
            __props__.__dict__["max_length"] = max_length
            __props__.__dict__["min_length"] = min_length
            __props__.__dict__["one_ofs"] = one_ofs
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["required"] = required
            __props__.__dict__["scope"] = scope
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["union"] = union
            __props__.__dict__["unique"] = unique
            __props__.__dict__["user_type"] = user_type
        super(AppUserSchemaProperty, __self__).__init__(
            'okta:index/appUserSchemaProperty:AppUserSchemaProperty',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            array_enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            array_one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyArrayOneOfArgs', 'AppUserSchemaPropertyArrayOneOfArgsDict']]]]] = None,
            array_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enums: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            external_name: Optional[pulumi.Input[_builtins.str]] = None,
            external_namespace: Optional[pulumi.Input[_builtins.str]] = None,
            index: Optional[pulumi.Input[_builtins.str]] = None,
            master: Optional[pulumi.Input[_builtins.str]] = None,
            max_length: Optional[pulumi.Input[_builtins.int]] = None,
            min_length: Optional[pulumi.Input[_builtins.int]] = None,
            one_ofs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyOneOfArgs', 'AppUserSchemaPropertyOneOfArgsDict']]]]] = None,
            permissions: Optional[pulumi.Input[_builtins.str]] = None,
            required: Optional[pulumi.Input[_builtins.bool]] = None,
            scope: Optional[pulumi.Input[_builtins.str]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            union: Optional[pulumi.Input[_builtins.bool]] = None,
            unique: Optional[pulumi.Input[_builtins.str]] = None,
            user_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'AppUserSchemaProperty':
        """
        Get an existing AppUserSchemaProperty resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The Application's ID the user custom schema property should be assigned to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyArrayOneOfArgs', 'AppUserSchemaPropertyArrayOneOfArgsDict']]]] array_one_ofs: Display name and value an enum array can be set to.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] array_type: The type of the array elements if `type` is set to `array`
        :param pulumi.Input[_builtins.str] description: The description of the user schema property.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[_builtins.str] external_name: External name of the user schema property.
        :param pulumi.Input[_builtins.str] external_namespace: External namespace of the user schema property.
        :param pulumi.Input[_builtins.str] index: Subschema unique string identifier
        :param pulumi.Input[_builtins.str] master: Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        :param pulumi.Input[_builtins.int] max_length: The maximum length of the user property value. Only applies to type `string`
        :param pulumi.Input[_builtins.int] min_length: The minimum length of the user property value. Only applies to type `string`
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppUserSchemaPropertyOneOfArgs', 'AppUserSchemaPropertyOneOfArgsDict']]]] one_ofs: Array of maps containing a mapping for display name to enum value.
               	- 'const' - (Required) value mapping to member of 'enum'.
               	- 'title' - (Required) display name for the enum value.
        :param pulumi.Input[_builtins.str] permissions: Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        :param pulumi.Input[_builtins.bool] required: Whether the subschema is required
        :param pulumi.Input[_builtins.str] scope: determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        :param pulumi.Input[_builtins.str] title: Subschema title (display name)
        :param pulumi.Input[_builtins.str] type: The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        :param pulumi.Input[_builtins.bool] union: If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        :param pulumi.Input[_builtins.str] unique: Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        :param pulumi.Input[_builtins.str] user_type: User type ID. By default, it is `default`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppUserSchemaPropertyState.__new__(_AppUserSchemaPropertyState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["array_enums"] = array_enums
        __props__.__dict__["array_one_ofs"] = array_one_ofs
        __props__.__dict__["array_type"] = array_type
        __props__.__dict__["description"] = description
        __props__.__dict__["enums"] = enums
        __props__.__dict__["external_name"] = external_name
        __props__.__dict__["external_namespace"] = external_namespace
        __props__.__dict__["index"] = index
        __props__.__dict__["master"] = master
        __props__.__dict__["max_length"] = max_length
        __props__.__dict__["min_length"] = min_length
        __props__.__dict__["one_ofs"] = one_ofs
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["required"] = required
        __props__.__dict__["scope"] = scope
        __props__.__dict__["title"] = title
        __props__.__dict__["type"] = type
        __props__.__dict__["union"] = union
        __props__.__dict__["unique"] = unique
        __props__.__dict__["user_type"] = user_type
        return AppUserSchemaProperty(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Application's ID the user custom schema property should be assigned to.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter(name="arrayEnums")
    def array_enums(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values that an array property's items can be set to.
        """
        return pulumi.get(self, "array_enums")

    @_builtins.property
    @pulumi.getter(name="arrayOneOfs")
    def array_one_ofs(self) -> pulumi.Output[Optional[Sequence['outputs.AppUserSchemaPropertyArrayOneOf']]]:
        """
        Display name and value an enum array can be set to.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "array_one_ofs")

    @_builtins.property
    @pulumi.getter(name="arrayType")
    def array_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The type of the array elements if `type` is set to `array`
        """
        return pulumi.get(self, "array_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the user schema property.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enums(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Array of values a primitive property can be set to. See `array_enum` for arrays.
        """
        return pulumi.get(self, "enums")

    @_builtins.property
    @pulumi.getter(name="externalName")
    def external_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        External name of the user schema property.
        """
        return pulumi.get(self, "external_name")

    @_builtins.property
    @pulumi.getter(name="externalNamespace")
    def external_namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        External namespace of the user schema property.
        """
        return pulumi.get(self, "external_namespace")

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Output[_builtins.str]:
        """
        Subschema unique string identifier
        """
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter
    def master(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Master priority for the user schema property. It can be set to `PROFILE_MASTER` or `OKTA`
        """
        return pulumi.get(self, "master")

    @_builtins.property
    @pulumi.getter(name="maxLength")
    def max_length(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "max_length")

    @_builtins.property
    @pulumi.getter(name="minLength")
    def min_length(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The minimum length of the user property value. Only applies to type `string`
        """
        return pulumi.get(self, "min_length")

    @_builtins.property
    @pulumi.getter(name="oneOfs")
    def one_ofs(self) -> pulumi.Output[Optional[Sequence['outputs.AppUserSchemaPropertyOneOf']]]:
        """
        Array of maps containing a mapping for display name to enum value.
        	- 'const' - (Required) value mapping to member of 'enum'.
        	- 'title' - (Required) display name for the enum value.
        """
        return pulumi.get(self, "one_ofs")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Access control permissions for the property. It can be set to `READ_WRITE`, `READ_ONLY`, `HIDE`. Default: `READ_ONLY`
        """
        return pulumi.get(self, "permissions")

    @_builtins.property
    @pulumi.getter
    def required(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the subschema is required
        """
        return pulumi.get(self, "required")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        determines whether an app user attribute can be set at the Personal `SELF` or Group `NONE` level. Default value is `NONE`.
        """
        return pulumi.get(self, "scope")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        Subschema title (display name)
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the schema property. It can be `string`, `boolean`, `number`, `integer`, `array`, or `object`
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def union(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If `type` is set to `array`, used to set whether attribute value is determined by group priority `false`, or combine values across groups `true`. Can not be set to `true` if `scope` is set to `SELF`.
        """
        return pulumi.get(self, "union")

    @_builtins.property
    @pulumi.getter
    def unique(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Whether the property should be unique. It can be set to `UNIQUE_VALIDATED` or `NOT_UNIQUE`.
        """
        return pulumi.get(self, "unique")

    @_builtins.property
    @pulumi.getter(name="userType")
    def user_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User type ID. By default, it is `default`
        """
        return pulumi.get(self, "user_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppGroupAssignmentsArgs', 'AppGroupAssignments']

@pulumi.input_type
class AppGroupAssignmentsArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]] = None):
        """
        The set of arguments for constructing a AppGroupAssignments resource.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]] groups: A group to assign to this application
        """
        pulumi.set(__self__, "app_id", app_id)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]:
        """
        A group to assign to this application
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]):
        pulumi.set(self, "groups", value)


@pulumi.input_type
class _AppGroupAssignmentsState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]] = None):
        """
        Input properties used for looking up and filtering AppGroupAssignments resources.

        :param pulumi.Input[_builtins.str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]] groups: A group to assign to this application
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]:
        """
        A group to assign to this application
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppGroupAssignmentsGroupArgs']]]]):
        pulumi.set(self, "groups", value)


@pulumi.type_token("okta:index/appGroupAssignments:AppGroupAssignments")
class AppGroupAssignments(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppGroupAssignmentsGroupArgs', 'AppGroupAssignmentsGroupArgsDict']]]]] = None,
                 __props__=None):
        """
        Assigns groups to an application. This resource allows you to create multiple App Group assignments.

        **Important**: Do not use `for_each` on this resource to iterate over groups for the same `app_id`. This resource's Read implementation fetches **all** groups currently assigned to the app from the Okta API — not just the ones declared in config. When multiple instances share the same `app_id`, the following infinite loop occurs on every apply:

        1. Each instance's update deletes the groups it does not own from Okta.
        2. Each instance's Read (called at the end of update) re-fetches all groups from the API and absorbs the other instance's groups back into state as drift.
        3. State after apply is identical to state before apply — the plan never converges and the same diff reappears on every `pulumi preview`.

        Since this resource natively supports multiple `group` blocks, use a `dynamic` block instead:

        **Bad** — creates two conflicting resource instances for the same app:
        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        this = []
        for range in [{"value": i} for i in range(0, std.index.toset(input=[
            group-a,
            group-b,
        ]).result)]:
            this.append(okta.AppGroupAssignments(f"this-{range['value']}",
                app_id=this_okta_app_bookmark["id"],
                groups=[{
                    "id": range["value"],
                }]))
        ```

        **Good** — a single resource instance manages all groups for the app:
        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        this = okta.AppGroupAssignments("this",
            groups=[{
                "id": entry["value"],
            } for entry in [{"key": k, "value": v} for k, v in std.index.toset(input=[
                "group-a",
                "group-b",
            ])["result"].items()]],
            app_id=this_okta_app_bookmark["id"])
        ```

        > **Note:** Using `for_each` on this resource is safe when each instance targets a **different** `app_id`, for example when assigning the same group to multiple applications.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        example = okta.AppGroupAssignments("example",
            app_id="<app id>",
            groups=[
                {
                    "id": "<group id>",
                    "priority": 1,
                },
                {
                    "id": "<another group id>",
                    "priority": 2,
                    "profile": json.dumps({
                        "application profile field": "application profile value",
                    }),
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appGroupAssignments:AppGroupAssignments example <app_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppGroupAssignmentsGroupArgs', 'AppGroupAssignmentsGroupArgsDict']]]] groups: A group to assign to this application
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppGroupAssignmentsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Assigns groups to an application. This resource allows you to create multiple App Group assignments.

        **Important**: Do not use `for_each` on this resource to iterate over groups for the same `app_id`. This resource's Read implementation fetches **all** groups currently assigned to the app from the Okta API — not just the ones declared in config. When multiple instances share the same `app_id`, the following infinite loop occurs on every apply:

        1. Each instance's update deletes the groups it does not own from Okta.
        2. Each instance's Read (called at the end of update) re-fetches all groups from the API and absorbs the other instance's groups back into state as drift.
        3. State after apply is identical to state before apply — the plan never converges and the same diff reappears on every `pulumi preview`.

        Since this resource natively supports multiple `group` blocks, use a `dynamic` block instead:

        **Bad** — creates two conflicting resource instances for the same app:
        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        this = []
        for range in [{"value": i} for i in range(0, std.index.toset(input=[
            group-a,
            group-b,
        ]).result)]:
            this.append(okta.AppGroupAssignments(f"this-{range['value']}",
                app_id=this_okta_app_bookmark["id"],
                groups=[{
                    "id": range["value"],
                }]))
        ```

        **Good** — a single resource instance manages all groups for the app:
        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        this = okta.AppGroupAssignments("this",
            groups=[{
                "id": entry["value"],
            } for entry in [{"key": k, "value": v} for k, v in std.index.toset(input=[
                "group-a",
                "group-b",
            ])["result"].items()]],
            app_id=this_okta_app_bookmark["id"])
        ```

        > **Note:** Using `for_each` on this resource is safe when each instance targets a **different** `app_id`, for example when assigning the same group to multiple applications.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        example = okta.AppGroupAssignments("example",
            app_id="<app id>",
            groups=[
                {
                    "id": "<group id>",
                    "priority": 1,
                },
                {
                    "id": "<another group id>",
                    "priority": 2,
                    "profile": json.dumps({
                        "application profile field": "application profile value",
                    }),
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appGroupAssignments:AppGroupAssignments example <app_id>
        ```


        :param str resource_name: The name of the resource.
        :param AppGroupAssignmentsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppGroupAssignmentsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppGroupAssignmentsGroupArgs', 'AppGroupAssignmentsGroupArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppGroupAssignmentsArgs.__new__(AppGroupAssignmentsArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["groups"] = groups
        super(AppGroupAssignments, __self__).__init__(
            'okta:index/appGroupAssignments:AppGroupAssignments',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppGroupAssignmentsGroupArgs', 'AppGroupAssignmentsGroupArgsDict']]]]] = None) -> 'AppGroupAssignments':
        """
        Get an existing AppGroupAssignments resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The ID of the application to assign a group to.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppGroupAssignmentsGroupArgs', 'AppGroupAssignmentsGroupArgsDict']]]] groups: A group to assign to this application
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppGroupAssignmentsState.__new__(_AppGroupAssignmentsState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["groups"] = groups
        return AppGroupAssignments(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the application to assign a group to.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Optional[Sequence['outputs.AppGroupAssignmentsGroup']]]:
        """
        A group to assign to this application
        """
        return pulumi.get(self, "groups")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAdminRoleCustomResult',
    'AwaitableGetAdminRoleCustomResult',
    'get_admin_role_custom',
    'get_admin_role_custom_output',
]

@pulumi.output_type
class GetAdminRoleCustomResult:
    """
    A collection of values returned by getAdminRoleCustom.
    """
    def __init__(__self__, description=None, id=None, label=None, permissions=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if permissions and not isinstance(permissions, list):
            raise TypeError("Expected argument 'permissions' to be a list")
        pulumi.set(__self__, "permissions", permissions)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        A human-readable description of the custom role.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for the custom role. Accepts the role ID or label.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        The name given to the custom role.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Sequence[_builtins.str]:
        """
        The permissions that the custom role grants.
        """
        return pulumi.get(self, "permissions")


class AwaitableGetAdminRoleCustomResult(GetAdminRoleCustomResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAdminRoleCustomResult(
            description=self.description,
            id=self.id,
            label=self.label,
            permissions=self.permissions)


def get_admin_role_custom(id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAdminRoleCustomResult:
    """
    Use this data source to retrieve a custom admin role from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_admin_role_custom(id="<role_id>")
    ```


    :param _builtins.str id: The unique identifier for the custom role. Accepts the role ID or label.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAdminRoleCustom:getAdminRoleCustom', __args__, opts=opts, typ=GetAdminRoleCustomResult).value

    return AwaitableGetAdminRoleCustomResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        permissions=pulumi.get(__ret__, 'permissions'))
def get_admin_role_custom_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAdminRoleCustomResult]:
    """
    Use this data source to retrieve a custom admin role from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_admin_role_custom(id="<role_id>")
    ```


    :param _builtins.str id: The unique identifier for the custom role. Accepts the role ID or label.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAdminRoleCustom:getAdminRoleCustom', __args__, opts=opts, typ=GetAdminRoleCustomResult)
    return __ret__.apply(lambda __response__: GetAdminRoleCustomResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        permissions=pulumi.get(__response__, 'permissions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PushGroupArgs', 'PushGroup']

@pulumi.input_type
class PushGroupArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 source_group_id: pulumi.Input[_builtins.str],
                 app_config: Optional[pulumi.Input['PushGroupAppConfigArgs']] = None,
                 delete_target_group_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PushGroup resource.

        :param pulumi.Input[_builtins.str] app_id: The ID of the Okta Application.
        :param pulumi.Input[_builtins.str] source_group_id: The ID of the source group in Okta.
        :param pulumi.Input['PushGroupAppConfigArgs'] app_config: Additional app configuration for group push mappings. Currently only required for Active Directory.
        :param pulumi.Input[_builtins.bool] delete_target_group_on_destroy: Whether to delete the target group when the push group mapping is destroyed. Default is true.
        :param pulumi.Input[_builtins.str] status: The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of the target group.
        :param pulumi.Input[_builtins.str] target_group_name: The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "source_group_id", source_group_id)
        if app_config is not None:
            pulumi.set(__self__, "app_config", app_config)
        if delete_target_group_on_destroy is not None:
            pulumi.set(__self__, "delete_target_group_on_destroy", delete_target_group_on_destroy)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if target_group_name is not None:
            pulumi.set(__self__, "target_group_name", target_group_name)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the source group in Okta.
        """
        return pulumi.get(self, "source_group_id")

    @source_group_id.setter
    def source_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_group_id", value)

    @_builtins.property
    @pulumi.getter(name="appConfig")
    def app_config(self) -> Optional[pulumi.Input['PushGroupAppConfigArgs']]:
        """
        Additional app configuration for group push mappings. Currently only required for Active Directory.
        """
        return pulumi.get(self, "app_config")

    @app_config.setter
    def app_config(self, value: Optional[pulumi.Input['PushGroupAppConfigArgs']]):
        pulumi.set(self, "app_config", value)

    @_builtins.property
    @pulumi.getter(name="deleteTargetGroupOnDestroy")
    def delete_target_group_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to delete the target group when the push group mapping is destroyed. Default is true.
        """
        return pulumi.get(self, "delete_target_group_on_destroy")

    @delete_target_group_on_destroy.setter
    def delete_target_group_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_target_group_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target group.
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupName")
    def target_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        return pulumi.get(self, "target_group_name")

    @target_group_name.setter
    def target_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_name", value)


@pulumi.input_type
class _PushGroupState:
    def __init__(__self__, *,
                 app_config: Optional[pulumi.Input['PushGroupAppConfigArgs']] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_target_group_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PushGroup resources.

        :param pulumi.Input['PushGroupAppConfigArgs'] app_config: Additional app configuration for group push mappings. Currently only required for Active Directory.
        :param pulumi.Input[_builtins.str] app_id: The ID of the Okta Application.
        :param pulumi.Input[_builtins.bool] delete_target_group_on_destroy: Whether to delete the target group when the push group mapping is destroyed. Default is true.
        :param pulumi.Input[_builtins.str] source_group_id: The ID of the source group in Okta.
        :param pulumi.Input[_builtins.str] status: The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of the target group.
        :param pulumi.Input[_builtins.str] target_group_name: The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        if app_config is not None:
            pulumi.set(__self__, "app_config", app_config)
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if delete_target_group_on_destroy is not None:
            pulumi.set(__self__, "delete_target_group_on_destroy", delete_target_group_on_destroy)
        if source_group_id is not None:
            pulumi.set(__self__, "source_group_id", source_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if target_group_name is not None:
            pulumi.set(__self__, "target_group_name", target_group_name)

    @_builtins.property
    @pulumi.getter(name="appConfig")
    def app_config(self) -> Optional[pulumi.Input['PushGroupAppConfigArgs']]:
        """
        Additional app configuration for group push mappings. Currently only required for Active Directory.
        """
        return pulumi.get(self, "app_config")

    @app_config.setter
    def app_config(self, value: Optional[pulumi.Input['PushGroupAppConfigArgs']]):
        pulumi.set(self, "app_config", value)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter(name="deleteTargetGroupOnDestroy")
    def delete_target_group_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to delete the target group when the push group mapping is destroyed. Default is true.
        """
        return pulumi.get(self, "delete_target_group_on_destroy")

    @delete_target_group_on_destroy.setter
    def delete_target_group_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "delete_target_group_on_destroy", value)

    @_builtins.property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the source group in Okta.
        """
        return pulumi.get(self, "source_group_id")

    @source_group_id.setter
    def source_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_group_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target group.
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_id", value)

    @_builtins.property
    @pulumi.getter(name="targetGroupName")
    def target_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        return pulumi.get(self, "target_group_name")

    @target_group_name.setter
    def target_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_group_name", value)


@pulumi.type_token("okta:index/pushGroup:PushGroup")
class PushGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_config: Optional[pulumi.Input[Union['PushGroupAppConfigArgs', 'PushGroupAppConfigArgsDict']]] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_target_group_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates a Push Group assignment for an Application in Okta.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.app.Swa("test",
            app_links_json=json.dumps({
                "deelhr_link": True,
            }),
            label="Deel HR",
            preconfigured_app="deelhr",
            status="ACTIVE",
            user_name_template_type="BUILT_IN")
        test_group = okta.group.Group("test", name="Some Test Push Group")
        sample = okta.PushGroup("sample",
            app_id=test.id,
            source_group_id=test_group.id,
            status="ACTIVE",
            delete_target_group_on_destroy=True)
        ad_sample = okta.PushGroup("ad_sample",
            app_id=test.id,
            source_group_id=test_group.id,
            status="ACTIVE",
            app_config={
                "distinguished_name": "CN=Test,OU=Groups,DC=example,DC=com",
                "group_scope": "DOMAIN_LOCAL",
                "group_type": "SECURITY",
                "sam_account_name": "something",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/pushGroup:PushGroup example <app_id>/<push_group_mapping_id>
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['PushGroupAppConfigArgs', 'PushGroupAppConfigArgsDict']] app_config: Additional app configuration for group push mappings. Currently only required for Active Directory.
        :param pulumi.Input[_builtins.str] app_id: The ID of the Okta Application.
        :param pulumi.Input[_builtins.bool] delete_target_group_on_destroy: Whether to delete the target group when the push group mapping is destroyed. Default is true.
        :param pulumi.Input[_builtins.str] source_group_id: The ID of the source group in Okta.
        :param pulumi.Input[_builtins.str] status: The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of the target group.
        :param pulumi.Input[_builtins.str] target_group_name: The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PushGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a Push Group assignment for an Application in Okta.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.app.Swa("test",
            app_links_json=json.dumps({
                "deelhr_link": True,
            }),
            label="Deel HR",
            preconfigured_app="deelhr",
            status="ACTIVE",
            user_name_template_type="BUILT_IN")
        test_group = okta.group.Group("test", name="Some Test Push Group")
        sample = okta.PushGroup("sample",
            app_id=test.id,
            source_group_id=test_group.id,
            status="ACTIVE",
            delete_target_group_on_destroy=True)
        ad_sample = okta.PushGroup("ad_sample",
            app_id=test.id,
            source_group_id=test_group.id,
            status="ACTIVE",
            app_config={
                "distinguished_name": "CN=Test,OU=Groups,DC=example,DC=com",
                "group_scope": "DOMAIN_LOCAL",
                "group_type": "SECURITY",
                "sam_account_name": "something",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/pushGroup:PushGroup example <app_id>/<push_group_mapping_id>
        ```


        :param str resource_name: The name of the resource.
        :param PushGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PushGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_config: Optional[pulumi.Input[Union['PushGroupAppConfigArgs', 'PushGroupAppConfigArgsDict']]] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delete_target_group_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 target_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PushGroupArgs.__new__(PushGroupArgs)

            __props__.__dict__["app_config"] = app_config
            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["delete_target_group_on_destroy"] = delete_target_group_on_destroy
            if source_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_group_id'")
            __props__.__dict__["source_group_id"] = source_group_id
            __props__.__dict__["status"] = status
            __props__.__dict__["target_group_id"] = target_group_id
            __props__.__dict__["target_group_name"] = target_group_name
        super(PushGroup, __self__).__init__(
            'okta:index/pushGroup:PushGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_config: Optional[pulumi.Input[Union['PushGroupAppConfigArgs', 'PushGroupAppConfigArgsDict']]] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            delete_target_group_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            source_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            target_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            target_group_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'PushGroup':
        """
        Get an existing PushGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['PushGroupAppConfigArgs', 'PushGroupAppConfigArgsDict']] app_config: Additional app configuration for group push mappings. Currently only required for Active Directory.
        :param pulumi.Input[_builtins.str] app_id: The ID of the Okta Application.
        :param pulumi.Input[_builtins.bool] delete_target_group_on_destroy: Whether to delete the target group when the push group mapping is destroyed. Default is true.
        :param pulumi.Input[_builtins.str] source_group_id: The ID of the source group in Okta.
        :param pulumi.Input[_builtins.str] status: The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        :param pulumi.Input[_builtins.str] target_group_id: The ID of the target group.
        :param pulumi.Input[_builtins.str] target_group_name: The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PushGroupState.__new__(_PushGroupState)

        __props__.__dict__["app_config"] = app_config
        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["delete_target_group_on_destroy"] = delete_target_group_on_destroy
        __props__.__dict__["source_group_id"] = source_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["target_group_id"] = target_group_id
        __props__.__dict__["target_group_name"] = target_group_name
        return PushGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appConfig")
    def app_config(self) -> pulumi.Output[Optional['outputs.PushGroupAppConfig']]:
        """
        Additional app configuration for group push mappings. Currently only required for Active Directory.
        """
        return pulumi.get(self, "app_config")

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Okta Application.
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter(name="deleteTargetGroupOnDestroy")
    def delete_target_group_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to delete the target group when the push group mapping is destroyed. Default is true.
        """
        return pulumi.get(self, "delete_target_group_on_destroy")

    @_builtins.property
    @pulumi.getter(name="sourceGroupId")
    def source_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the source group in Okta.
        """
        return pulumi.get(self, "source_group_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the push group mapping. Valid values: `ACTIVE` and `INACTIVE`
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the target group.
        """
        return pulumi.get(self, "target_group_id")

    @_builtins.property
    @pulumi.getter(name="targetGroupName")
    def target_group_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the target group for the group push mapping. This is used when creating a new downstream group. If the group already exists, it links to the existing group. If not specified, the name of the source group will be used as the name of the target group. Setting a target group name only works if you have unchecked 'Rename app groups to match group name in Okta' in the push groups settings UI.
        """
        return pulumi.get(self, "target_group_name")

